@@ -1206,12 +1206,12 @@ logsender(e, msgid)
 	register char *p;
 	char hbuf[MAXNAME + 1];	/* EAI:ok; restricted to short size */
 	char sbuf[MAXLINE + 1]; /* EAI:ok; XREF: see also MSGIDLOGLEN */
-#if SYSLOG_BUFSIZE >= 256
-# if _FFR_8BITENVADDR
+# if SYSLOG_BUFSIZE >= 256
+#  if _FFR_8BITENVADDR
 	char xbuf[XBUFLEN + 1];	/* EAI:ok */
-# endif
+#  endif
 	char *xstr;
-#endif
+# endif
 
 	if (bitset(EF_RESPONSE, e->e_flags))
 		name = "[RESPONSE]";
@@ -1235,19 +1235,19 @@ logsender(e, msgid)
 		}
 	}
 
-#if SYSLOG_BUFSIZE >= 256
+# if SYSLOG_BUFSIZE >= 256
 	sbp = sbuf;
 	if (NULL != e->e_from.q_paddr)
 	{
 		xstr = e->e_from.q_paddr;
-# if _FFR_8BITENVADDR
+#  if _FFR_8BITENVADDR
 		(void) dequote_internal_chars(e->e_from.q_paddr, xbuf, sizeof(xbuf));
 		xstr = xbuf;
-# endif
+#  endif
 	}
 	else
 		xstr = "<NONE>";
-#if _FFR_SE_TA_ID
+#  if _FFR_SE_TA_ID
 	if (e->e_s_se != NULL)
 	{
 		(void) sm_snprintf(sbp, SPACELEFT(sbuf, sbp),
@@ -1262,17 +1262,17 @@ logsender(e, msgid)
 			S_TA_ID "=%s, ", e->e_s_ta);
 		sbp += strlen(sbp);
 	}
-#endif
+#  endif /*  _FFR_SE_TA_ID */
 	(void) sm_snprintf(sbp, SPACELEFT(sbuf, sbp),
 		"from=%.200s, size=%ld, class=%hd, nrcpts=%d", xstr,
 		PRT_NONNEGL(e->e_msgsize), e->e_class, e->e_nrcpts);
 	sbp += strlen(sbp);
 	if (msgid != NULL)
 	{
-# if _FFR_8BITENVADDR
+#  if _FFR_8BITENVADDR
 		(void) dequote_internal_chars(msgid, xbuf, sizeof(xbuf));
 		msgid = xbuf;
-# endif
+#  endif
 		(void) sm_snprintf(sbp, SPACELEFT(sbuf, sbp),
 				", msgid=%.*s", MSGIDLOGLEN, msgid);
 		sbp += strlen(sbp);
@@ -1297,20 +1297,20 @@ logsender(e, msgid)
 				", daemon=%.20s", p);
 		sbp += strlen(sbp);
 	}
-# if _FFR_LOG_MORE1
+#  if _FFR_LOG_MORE1
 	LOG_MORE(sbuf, sbp);
-#  if SASL
+#   if SASL
 	p = macvalue(macid("{auth_type}"), e);
 	if (SM_IS_EMPTY(p))
 		p = "NONE";
 	(void) sm_snprintf(sbp, SPACELEFT(sbuf, sbp), ", auth=%.20s", p);
 	sbp += strlen(sbp);
-#  endif /* SASL */
-# endif /* _FFR_LOG_MORE1 */
+#   endif /* SASL */
+#  endif /* _FFR_LOG_MORE1 */
 	LOG_ENVID(sbuf, sbp, e);
 	sm_syslog(LOG_INFO, e->e_id, "%.*s, relay=%s", FIRSTLOGLEN, sbuf, name);
 
-#else /* SYSLOG_BUFSIZE >= 256 */
+# else /* SYSLOG_BUFSIZE >= 256 */
 
 	sm_syslog(LOG_INFO, e->e_id,
 		  "from=%s",
@@ -1341,7 +1341,7 @@ logsender(e, msgid)
 	}
 	sm_syslog(LOG_INFO, e->e_id,
 		  "%.400srelay=%s", sbuf, name);
-#endif /* SYSLOG_BUFSIZE >= 256 */
+# endif /* SYSLOG_BUFSIZE >= 256 */
 }
 
 /*
