@@ -43,10 +43,10 @@
 
 /* $Id: sm_resolve.h,v 8.9 2013-11-22 20:51:56 ca Exp $ */
 
-#if DNSMAP || DANE
-# ifndef __ROKEN_RESOLVE_H__
-#  define __ROKEN_RESOLVE_H__
+#ifndef SM_RESOLVE_H
+#define SM_RESOLVE_H
 
+#if DNSMAP || DANE
 /* We use these, but they are not always present in <arpa/nameser.h> */
 
 #  ifndef T_TXT
@@ -128,9 +128,6 @@ typedef struct
 	RESOURCE_RECORD_T	*dns_r_head;
 } DNS_REPLY_T;
 
-#define SM_DNS_FL_EDNS0		0x01
-#define SM_DNS_FL_DNSSEC	0x02
-
 /* flags for parse_dns_reply() et.al. */
 #define RR_AS_TEXT	0x01	/* convert some RRs to text, e.g., TLSA */
 #define RR_RAW		0x02	/* return some RRs as "raw" data */
@@ -166,14 +163,6 @@ int getttlfromstring __P((const char *));
 int tstdns_search __P((const char *, int, int, u_char *, int));
 int tstdns_querydomain  __P((const char *, const char *, int, int, unsigned char *, int));
 
-#   ifdef _DEFINE_SMR_GLOBALS
-#    define SMR_EXTERN
-#   else
-#    define SMR_EXTERN extern
-#   endif
-SMR_EXTERN char *NameSearchList;
-#   undef SMR_EXTERN
-extern int	nsportip __P((char *));
 #  endif /* DNSSEC_TEST*/
 
 #ifndef RES_TRUSTAD
@@ -181,5 +170,17 @@ extern int	nsportip __P((char *));
 #endif
 #define SM_RES_DNSSEC (RES_USE_EDNS0|RES_USE_DNSSEC|RES_TRUSTAD)
 
-# endif /* ! __ROKEN_RESOLVE_H__ */
 #endif /* DNSMAP || DANE */
+
+#if DNSSEC_TEST || _FFR_NAMESERVER
+# ifdef _DEFINE_SMR_GLOBALS
+#  define SMR_EXTERN
+# else
+#  define SMR_EXTERN extern
+# endif
+SMR_EXTERN char *NameSearchList;
+# undef SMR_EXTERN
+extern int	nsportip __P((char *));
+#endif /* DNSSEC_TEST || _FFR_NAMESERVER */
+
+#endif /* ! SM_RESOLVE_H */
