@@ -2691,7 +2691,7 @@ smtprcptstat(to, m, mci, e)
 					sm_dprintf("rcpt=%s, rcpt_status=%s\n",
 						to->q_paddr, to->q_rstatus);
 				if (LogLevel > 8)
-#if _FFR_SE_TA_ID
+# if _FFR_SE_TA_ID
 					sm_syslog(LOG_DEBUG, e->e_id,
 						"%s%s%s%sto=%s, %s%s%s%s%s%s%s%srelay=%.100s [%.100s], reply=%s",
 						(e->e_c_ta != NULL) ? S_TA_ID : "",
@@ -2710,14 +2710,14 @@ smtprcptstat(to, m, mci, e)
 						mci->mci_host,
 						anynet_ntoa(&CurHostAddr),
 						to->q_rstatus);
-#else /* _FFR_SE_TA_ID */
+# else /* _FFR_SE_TA_ID */
 					sm_syslog(LOG_DEBUG, e->e_id,
 						"to=%s, relay=%.100s [%.100s], reply=%s",
 						to->q_paddr, mci->mci_host,
 						anynet_ntoa(&CurHostAddr),
 						to->q_rstatus);
-#endif /* _FFR_SE_TA_ID */
-				mci->mci_flags |= MCIF_SAMEDOMAIN;
+# endif /* _FFR_SE_TA_ID */
+				mci->mci_flags |= MCIF_SAMEDOMAIN_TA|MCIF_SAMEDOMAIN_SE;
 				to->q_flags |= QNOTSAMEDOMAIN;
 				break;
 			}
@@ -2842,9 +2842,9 @@ smtpdata(m, mci, e, ctladdr, xstart)
 			r = smtprcptstat(mci->mci_nextaddr, m, mci, e);
 			if (r != EX_OK)
 			{
-#if _FFR_SAMEDOMAIN
+# if _FFR_SAMEDOMAIN
 				if (tTd(68, 4))
-					sm_dprintf("pipelining: rcpt=%s, rc=%d, to=%s, MCIF_SAMEDOMAIN=%d, QNOTSAMEDOMAIN=%d\n", mci->mci_nextaddr->q_paddr, r, mci->mci_nextaddr->q_paddr, bitset(MCIF_SAMEDOMAIN, mci->mci_flags), bitset(QNOTSAMEDOMAIN, mci->mci_nextaddr->q_flags));
+					sm_dprintf("pipelining: rcpt=%s, rc=%d, to=%s, MCIF_SAMEDOMAIN_TA=%d,  MCIF_SAMEDOMAIN_SE=%d, QNOTSAMEDOMAIN=%d\n", mci->mci_nextaddr->q_paddr, r, mci->mci_nextaddr->q_paddr, bitset(MCIF_SAMEDOMAIN_TA, mci->mci_flags), bitset(MCIF_SAMEDOMAIN_SE, mci->mci_flags), bitset(QNOTSAMEDOMAIN, mci->mci_nextaddr->q_flags));
 				if (bitset(QNOTSAMEDOMAIN, mci->mci_nextaddr->q_flags))
 				{
 					if (tTd(68, 4))
@@ -2852,7 +2852,7 @@ smtpdata(m, mci, e, ctladdr, xstart)
 				}
 				else
 				{
-#endif /* _FFR_SAMEDOMAIN */
+# endif /* _FFR_SAMEDOMAIN */
 				markfailure(e, mci->mci_nextaddr, mci, r,
 					    false);
 				giveresponse(r, mci->mci_nextaddr->q_status, m,
@@ -2860,9 +2860,9 @@ smtpdata(m, mci, e, ctladdr, xstart)
 					     mci->mci_nextaddr);
 				if (r == EX_TEMPFAIL)
 					mci->mci_nextaddr->q_state = QS_RETRY;
-#if _FFR_SAMEDOMAIN
+# if _FFR_SAMEDOMAIN
 				}
-#endif
+# endif
 			}
 			mci->mci_nextaddr = mci->mci_nextaddr->q_pchain;
 		}
